@@ -7,10 +7,10 @@
 
 int main(int argc, char *argv[])
 {
-    QApplication::setOrganizationDomain("rubyx.co.uk");
+    QApplication::setApplicationName(RX_APPLICATION_NAME);
+    QApplication::setApplicationVersion(RX_APPLICATION_VERSION);
     QApplication::setOrganizationName("rx");
-    QApplication::setApplicationName("columbus");
-    QApplication::setApplicationVersion("0.8.1");
+    QApplication::setOrganizationDomain("rubyx.co.uk");
 
     QApplication            application (argc, argv);
     ApplicationController   controller;
