@@ -38,7 +38,7 @@ ColumbusDialogOptions::~ColumbusDialogOptions()
     delete this->d;
 }
 
-void ColumbusDialogOptions::setController(ColumbusController *controller)
+void ColumbusDialogOptions::setController(ApplicationController *controller)
 {
     ColumbusDialog::setController(controller);
 
@@ -81,7 +81,6 @@ void ColumbusDialogOptions::addOption(const QString &key)
 
     button->setPickSelector(selector);
     button->setValueText(selector->currentValueText());
-    //button->setValueLayout(QMaemo5ValueButton::ValueUnderTextCentered);
 
     QObject::connect(selector, SIGNAL(selected(QString)), this, SLOT(onOptionChanged(QString)));
     d->layout->addWidget(button);
