@@ -3,17 +3,23 @@
 
 #include "widgets/ColumbusDialog.h"
 
+class ColumbusDialogToolsPrivate;
+
 class ColumbusDialogTools : public ColumbusDialog
 {
     Q_OBJECT
 
 public:
     explicit ColumbusDialogTools(QWidget *parent = 0);
+            ~ColumbusDialogTools();
 
     void setController(ApplicationController *controller);
 
+protected Q_SLOTS:
+    void onDialogFinished();
+
 private:
-    void setupUi();
+    ColumbusDialogToolsPrivate *d;
 };
 
 #endif // COLUMBUSDIALOGTOOLS_H
