@@ -15,7 +15,7 @@ public:
     explicit ColumbusStatisticsView(QWidget *parent = 0);
 
     QString friendlyName() const;
-    void setController(ColumbusController *controller);
+    void setController(ApplicationController *controller);
 
     void setupUi();
 
