@@ -20,6 +20,9 @@ public:
     ApplicationController*      controller         () const;
     void                     setController      (ApplicationController *controller);
 
+protected:
+    bool         eventFilter(QObject *object, QEvent *event);
+
 private slots:
     void         onLandscape                ();
     void         onPortrait                 ();
