@@ -4,6 +4,7 @@
 #include <QStyledItemDelegate>
 
 #include <rx/columbus/ColumbusModel.h>
+#include <rx/columbus/ColumbusWaypointModel.h>
 
 class WaypointListDelegatePrivate;
 
@@ -12,7 +13,7 @@ class WaypointListDelegate : public QStyledItemDelegate
     Q_OBJECT
 
 public:
-    explicit WaypointListDelegate(ColumbusModel *model, QObject *parent = 0);
+    explicit WaypointListDelegate(ColumbusModel *model, ColumbusWaypointModel *waypoints, QObject *parent = 0);
             ~WaypointListDelegate();
 
     void paint(QPainter *painter, const QStyleOptionViewItem &option, const QModelIndex &index) const;
